@@ -33,15 +33,15 @@ Add additional elements
 
 coerce 'Elive::StandardV2::_List' => from 'ArrayRef'
           => via {
-	      my @participants = grep {$_ ne ''} map {split(',')} @$_;
-	      Elive::StandardV2::_List->new(\@participants);
+	      my @items = grep {$_ ne ''} map {split(',')} @$_;
+	      Elive::StandardV2::_List->new(\@items);
 };
 
 coerce 'Elive::StandardV2::_List' => from 'Str'
           => via {
-	      my @participants = grep {$_ ne ''} split(',');
+	      my @items = grep {$_ ne ''} split(',');
 
-	      Elive::StandardV2::_List->new(\@participants);
+	      Elive::StandardV2::_List->new(\@items);
           };
 
 =head2 stringify
@@ -56,11 +56,10 @@ sub stringify {
     my $arr  = shift || $self;
     my $type = shift || $self->element_class;
 
-    $arr = [split(';', $arr)]
+    $arr = [split(',', $arr)]
 	if defined $arr && !Scalar::Util::reftype($arr);
 
     return join(',', sort map {Elive::Util::string($_, $type)} @$arr)
 }
 
-
 1;
